@@ -1,4 +1,5 @@
 use crate::arg::SqlArg;
+use std::collections::HashMap;
 
 pub trait Bind {
     /// Replace first ? with a value.
@@ -112,6 +113,8 @@ pub trait Bind {
     fn bind_nums(&self, args: &[&dyn SqlArg]) -> String;
 
     fn bind_name(&self, name: &dyn ToString, arg: &dyn SqlArg) -> String;
+
+    fn bind_names<'a>(&self, names: &HashMap<&'a str, String>) -> String;
 }
 
 impl Bind for &str {
@@ -236,6 +239,10 @@ impl Bind for &str {
     fn bind_name(&self, name: &dyn ToString, arg: &dyn SqlArg) -> String {
         (*self).to_string().bind_name(name, arg)
     }
+
+    fn bind_names<'a>(&self, names: &HashMap<&'a str, String>) -> String {
+        (*self).to_string().bind_names(names)
+    }
 }
 
 impl Bind for String {
@@ -415,6 +422,39 @@ impl Bind for String {
         let rep = format!(":{}:", &name.to_string());
         self.replace(&rep, &arg.sql_arg())
     }
+
+    fn bind_names<'a>(&self, names: &HashMap<&'a str, String>) -> String {
+        let mut res = String::new();
+        let mut key = String::new();
+        let mut wait_colon = false;
+        for ch in self.chars() {
+            if ch == ':' {
+                if wait_colon {
+                    if key.is_empty() {
+                        res.push(ch);
+                    } else {
+                        let skey = key.to_string();
+                        if let Some(value) = names.get(&*skey) {
+                            res.push_str(&value);
+                        }
+                        key = String::new();
+                    }
+                    wait_colon = false;
+                } else {
+                    wait_colon = true;
+                }
+            } else if wait_colon {
+                key.push(ch);
+            } else {
+                res.push(ch);
+            }
+        }
+        if wait_colon {
+            res.push(';');
+            res.push_str(&key);
+        }
+        res
+    }
 }
 
 #[cfg(test)]
@@ -484,4 +524,28 @@ mod tests {
 
         Ok(())
     }
+
+    #[test]
+    fn test_bind_names() -> Result<(), Box<dyn Error + Send + Sync>> {
+        let mut names = HashMap::new();
+        names.insert("aaa", 10.sql_arg());
+        names.insert("bbb", 20.sql_arg());
+        names.insert("ccc", "tt".sql_arg());
+        names.insert("ddd", 40.sql_arg());
+
+        let sql = SqlBuilder::insert_into("books")
+            .fields(&["title", "price"])
+            .values(&["'a_book', :aaa:"])
+            .values(&["'c_book', :ccc:"])
+            .values(&["'e_book', :eee:"])
+            .sql()?
+            .bind_names(&names);
+
+        assert_eq!(
+            "INSERT INTO books (title, price) VALUES ('a_book', 10), ('c_book', 'tt'), ('e_book', );",
+            &sql
+        );
+
+        Ok(())
+    }
 }
